function Lc_error(choice,in,Si_data);
%   SubFunction for Non-Linearity Error
%        The deviation for Linear Prediction and Small Deflection
%      choice = 2 : for circular plate
%               4 : for square plate
%      in(1) : Pressure(psi)
%      in(2) : turn
%      in(3) : Rw, Resistor Width (um)
%      in(4) : a , Plate Diameter/Width (um)
%      in(5) : h , Plate Thickness(um)
%      in(6) : sheet_r, Sheet Resistance
%      in(7) : Effective Length
%      in(8) : Temperature( C )
%  PS : Resistor Parameters have been set.

% ---------------------------------------------------------------
%   Unit Transformation

q=in(1)*6895;
turn=in(2);
Rw=in(3)*1e-6;
a =in(4)*1e-6;        
h =in(5)*1e-6;       
r_sheet=in(6);
RL=in(7)*1e-6;
Temp=in(8)+273;

% Resistor Parameters. -----
%    RL     : Length of the Resistor
%    RLsub  : Length of the Resistor going into the substrate
%    Rw     : Width of the Resistor
%    tl, tw : length/width of the turn around resistor
%    cl, cw : length/width of the contact pad before metal
tl=5e-6;    tw=5e-6;  
cl=8e-6;    cw=6e-6;
RLsub=3e-6;
PR=200 ;          % Parasitic Resistance  
Vin=5e3;          % input Voltage
E=150e9; v=0.27;

% Room Temp Piezoresistance Coeff. in the (100) plane  - from previous thesis
PI_l_300=1e-12*153.9;
PI_t_300=1e-12*-87.3;
P_NT=piezo(Si_data(2),Temp,Si_data(1));

%  PiezoResistive Coeff. in longutidual and transverse direction  
PI_l=PI_l_300*P_NT;
PI_t=PI_t_300*P_NT;

%  Resistor Sensitivity Calculation
F_par=E*(PI_l+v*PI_t)/(1-v*v);
F_per=E*(PI_t+v*PI_l)/(1-v*v);

G_par=F_par+1/(1-v);
G_per=F_per+(1-2*v)/(1-v);

R =r_sheet*( 2*turn*(RL+RLsub)/Rw + (2*turn-1)*tl/tw + 2*cl/cw )+PR;
NR=r_sheet*( 2*turn*(RLsub)/Rw + (2*turn-1)*tl/tw + 2*cl/cw )+PR;
Reff=R-NR;          

% Lineatiry Error Reference Voltage -- from small/large deflection
Vmax=Voltage_Out(choice,q,a,h,RL,Reff,NR,Vin,G_par,G_per);
m=Vmax/q;

% Programming Calculation
N=20;   div=q/N;         % divide Preuuse

% Varying Pressure @ Fixed Effective Length
for j=1:N+1
  P=q-div*(j-1);           % Current Pressure     
  if P==0
    Vout(j)=0;
  else
    Vout(j)=Voltage_Out(choice,P,a,h,RL,Reff,NR,Vin,G_par,G_per);
  end;
  x(j)=P;
    
  V_ideal(j)=m*P;        % Ideal Linear Voltage Output
  
  if Vout(j)==V_ideal(j)  
    Error(j)=0;  
  else 
    Error(j)=(Vout(j)-V_ideal(j))/Vmax;
  end;  
end;

plot_choice=round(mod(rand(1)*10,3));
if plot_choice==0
  plot(x/6895,Error*100,'bx');
elseif plot_choice==1
  plot(x/6895,Error*100,'mo');
elseif plot_choice==2
  plot(x/6895,Error*100,'rd');
else
  plot(x/6895,Error*100,'k^');
end;

title('Linearity Error');
xlabel('Effective Pressure (psi)');
ylabel('Linearity Error (%)');

return;
